#! /bin/sh

# When in clone of Git repository (see Vcs-Git in debian/control), one may use
# this script for building QTM packages

set -e

git clean -d -f -x
git reset --hard
git co upstream
git br -D master || true
git co -b master upstream
git merge debian -m "Build merge"

debuild -us -uc -I.git $@

